RnaBindingProtein: RnaBindingProtein

Description Public fields Active bindings Methods Examples

Description

assess RNA-binding protein binding sites, their structure and motif matches

Public fields

rbp

the gene symbol name of the protein

Active bindings

rbp

the gene symbol name of the protein

Methods

Public methods


Method new()

Creates a new instance of this [R6][R6::R6Class] class.

Usage
RnaBindingProtein$new(rbp, targetGene, cellType, motifs.meme.file = NA)
Arguments
targetGene

character, gene symbol presumably having associated rbp binding sites

cellType

character, currently "K562" or "HepG2"

motifs.meme.file

character, full path to an optional motifs file, calculated separately, describing motifs for the rbp

rpb

character, gene symbol identifier for the rbp


Method getEncodeCatalog()

Usage
RnaBindingProtein$getEncodeCatalog()
Returns

the table of RBPs/cellTypes for which we have bigBed files from ENCODE


Method getBindingTable()

Usage
RnaBindingProtein$getBindingTable()
Returns

the slightly processed and filtered data.frame version of the ENCODE bigbed


Method getAnnotationTypes()

the bioc annotatr class offers a large set of genic annotations, ultimately obtained from UCSC via TxDb.Hsapiens.UCSC.hg38.knownGene

Usage
RnaBindingProtein$getAnnotationTypes()
Returns

genic annotation types for hg38


Method start.igv()

start, and retain a reference to, an igvR for the current genome and targetGene

Usage
RnaBindingProtein$start.igv()
Returns

igv reference


Method getGenicRegions()

extract all genic regions, mulitiple types, no longer just 3' and 5' UTRs and CDS) for the targetGene

Usage
RnaBindingProtein$getGenicRegions()
Returns

data.frame


Method getAllGenicAnnotations()

access to the full whole genome annotations table

Usage
RnaBindingProtein$getAllGenicAnnotations()
Returns

data.frame


Method getBindingSites()

retrieve the rbp bindings sites within the specified region

Usage
RnaBindingProtein$getBindingSites(roi)
Arguments
roi

list with chrom, start, end fields

Returns

data.frame


Method getGeneRegion()

retrieve the chrom, start and end of the targetGene, if !na

Usage
RnaBindingProtein$getGeneRegion()
Returns

list with chrom, start end, geneSymbol fields


Method getBindingSites.inGenicRegions()

retrieve the rbp bindings which intersect with annotated genic regions of interest, currently UTRs and CDSfor the targetGene

Usage
RnaBindingProtein$getBindingSites.inGenicRegions(intersectionType = "within")
Arguments
intersectionType

character, one of "any" or "within"

Returns

data.frame


Method runMeme()

create fasta file from filtered rbp binding sites, run meme

Usage
RnaBindingProtein$runMeme(tag.name, bl.sitesFiltered)
Arguments
tagName

character something memorable and explanatory

top.quartiles.to.include

numeric, 1 or more

Returns

character string, the path to the meme html output


Method clone()

The objects of this class are cloneable with this method.

Usage
RnaBindingProtein$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

Examples

1
  rbp <- RnaBindingProtein("DDX3X", "path/to/ENCFF565FNW.bigBed", "K562", "path/to/ddx3x.meme")

paul-shannon/rnaBindingProteins documentation built on Feb. 14, 2022, 1:56 a.m.