Description Public fields Active bindings Methods Examples
assess RNA-binding protein binding sites, their structure and motif matches
rbpthe gene symbol name of the protein
rbpthe gene symbol name of the protein
new()Creates a new instance of this [R6][R6::R6Class] class.
RnaBindingProtein$new(rbp, targetGene, cellType, motifs.meme.file = NA)
targetGenecharacter, gene symbol presumably having associated rbp binding sites
cellTypecharacter, currently "K562" or "HepG2"
motifs.meme.filecharacter, full path to an optional motifs file, calculated separately, describing motifs for the rbp
rpbcharacter, gene symbol identifier for the rbp
getEncodeCatalog()RnaBindingProtein$getEncodeCatalog()
the table of RBPs/cellTypes for which we have bigBed files from ENCODE
getBindingTable()RnaBindingProtein$getBindingTable()
the slightly processed and filtered data.frame version of the ENCODE bigbed
getAnnotationTypes()the bioc annotatr class offers a large set of genic annotations, ultimately obtained from UCSC via TxDb.Hsapiens.UCSC.hg38.knownGene
RnaBindingProtein$getAnnotationTypes()
genic annotation types for hg38
start.igv()start, and retain a reference to, an igvR for the current genome and targetGene
RnaBindingProtein$start.igv()
igv reference
getGenicRegions()extract all genic regions, mulitiple types, no longer just 3' and 5' UTRs and CDS) for the targetGene
RnaBindingProtein$getGenicRegions()
data.frame
getAllGenicAnnotations()access to the full whole genome annotations table
RnaBindingProtein$getAllGenicAnnotations()
data.frame
getBindingSites()retrieve the rbp bindings sites within the specified region
RnaBindingProtein$getBindingSites(roi)
roilist with chrom, start, end fields
data.frame
getGeneRegion()retrieve the chrom, start and end of the targetGene, if !na
RnaBindingProtein$getGeneRegion()
list with chrom, start end, geneSymbol fields
getBindingSites.inGenicRegions()retrieve the rbp bindings which intersect with annotated genic regions of interest, currently UTRs and CDSfor the targetGene
RnaBindingProtein$getBindingSites.inGenicRegions(intersectionType = "within")
intersectionTypecharacter, one of "any" or "within"
data.frame
runMeme()create fasta file from filtered rbp binding sites, run meme
RnaBindingProtein$runMeme(tag.name, bl.sitesFiltered)
tagNamecharacter something memorable and explanatory
top.quartiles.to.includenumeric, 1 or more
character string, the path to the meme html output
clone()The objects of this class are cloneable with this method.
RnaBindingProtein$clone(deep = FALSE)
deepWhether to make a deep clone.
1 | rbp <- RnaBindingProtein("DDX3X", "path/to/ENCFF565FNW.bigBed", "K562", "path/to/ddx3x.meme")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.